@@ -25,13 +25,15 @@ import random
 import sqlite3
 import sys
 
-from . import crossref
-from . import csv_sources
-from . import debug
-from .file_cache import FileCache
-from . import orcid
-from . import ror
-from . import perf
+from alexandria3k import crossref
+from alexandria3k import csv_sources
+from alexandria3k import debug
+from alexandria3k.file_cache import FileCache
+from alexandria3k import orcid
+from alexandria3k import ror
+from alexandria3k import perf
+
+DESCRIPTION = "alexandria3k: Relational interface to publication metadata"
 
 # Default values for diverse data sources
 DOAJ_DEFAULT = "https://doaj.org/csv"
@@ -170,8 +172,8 @@ def database_counts(database):
     print(f"{count} references(s) with DOI")
 
 
-def parse_cli_arguments(parser, args=None):
-    """Parse command line arguments (or args e.g. when testing)"""
+def add_cli_arguments(parser):
+    """Add the available command-line arguments to the specified parser."""
 
     parser.add_argument(
         "-a",
@@ -193,18 +195,20 @@ def parse_cli_arguments(parser, args=None):
         nargs="+",
         type=str,
         default=[],
+        # NOTE: Keep in sync with list in debug.py
         help="""Output debuggging information as specfied by the arguments.
-    files-read: Output counts of data files read;
+    files-read: Counts of Crossref data files read;
     link: Record linking operations;
-    log-sql: Output executed SQL statements;
-    perf: Output performance timings;
-    populated-counts: Dump counts of the populated database;
-    populated-data: Dump the data of the populated database;
-    populated-reports: Output query results from the populated database;
-    progress: Report progress;
+    sql: Executed SQL statements;
+    perf: Performance timings;
+    populated-counts: Counts of the populated database;
+    populated-data: Data of the populated database;
+    populated-reports: Query results from the populated database;
+    progress: Report population progress;
+    sorted-tables: Topologically ordered Crossref query tables;
     stderr: Log to standard error;
-    virtual-counts: Dump counts of the virtual database;
-    virtual-data: Dump the data of the virtual database.
+    virtual-counts: Counts of the virtual database;
+    virtual-data: Data of the virtual database.
 """,
     )
     parser.add_argument(
@@ -263,12 +267,6 @@ def parse_cli_arguments(parser, args=None):
         type=str,
         help="Only add ORCID records that link to existing <persons> or <works>",
     )
-    parser.add_argument(
-        "-n",
-        "--normalize",
-        action="store_true",
-        help="Normalize relations in the populated Crossref database",
-    )
     parser.add_argument(
         "-o",
         "--output",
@@ -329,6 +327,10 @@ link-works-asjcs (link works with Scopus All Science Journal Classification Code
         """,
     )
 
+
+def parse_cli_arguments(parser, args=None):
+    """Parse command line arguments (or args e.g. when testing)"""
+    add_cli_arguments(parser)
     return expand_data_source(parser, parser.parse_args(args))
 
 
@@ -389,19 +391,30 @@ def expand_data_source(parser, args):
     else:
         parser.error(f"Unknown source name {args.data_source[0]}")
 
-    if args.query and not args.crossref:
+    if (args.query or args.query_file) and not args.crossref:
         parser.error("Missing Crossref data directory value")
 
+    if (args.query or args.query_file) and args.populate_db_path:
+        parser.error(
+            "Database population cannot be combined with direct queries. "
+            "Consider specifying --row-selection or --columns."
+        )
+
     return args
 
 
+def get_cli_parser():
+    """Return a CLI parser (used by sphinx-argparse)"""
+    parser = argparse.ArgumentParser(description=DESCRIPTION)
+    add_cli_arguments(parser)
+    return parser
+
+
 def main():
     # pylint: disable=too-many-branches
     # pylint: disable=too-many-statements
     """Program entry point"""
-    parser = argparse.ArgumentParser(
-        description="alexandria3k: Publication metadata interface"
-    )
+    parser = argparse.ArgumentParser(description=DESCRIPTION)
     args = parse_cli_arguments(parser)
 
     # Setup debug logging and performance monitoring
@@ -418,7 +431,9 @@ def main():
     if args.crossref:
         # pylint: disable-next=W0123
         sample = eval(f"lambda path: {args.sample}")
-        crossref_instance = crossref.Crossref(args.crossref, sample)
+        crossref_instance = crossref.Crossref(
+            args.crossref, sample, args.attach_databases
+        )
 
     if debug.enabled("virtual-counts"):
         # Streaming interface
@@ -441,7 +456,6 @@ def main():
             args.populate_db_path,
             args.columns,
             args.row_selection,
-            args.attach_databases,
         )
         debug.log("files-read", f"{FileCache.file_reads} files read")
         perf.log("Crossref table population")
