@@ -33,6 +33,15 @@ from alexandria3k.file_cache import FileCache
 DATABASE_PATH = "tests/tmp/crossref.db"
 ATTACHED_DATABASE_PATH = "tests/tmp/attached.db"
 
+def populate_attached():
+    """Create and populate an attached database"""
+    ensure_unlinked(ATTACHED_DATABASE_PATH)
+    attached = sqlite3.connect(ATTACHED_DATABASE_PATH)
+    attached.execute("CREATE TABLE s_works(doi)")
+    attached.execute("INSERT INTO s_works VALUES('10.1016/j.bjps.2022.04.046')")
+    attached.commit()
+    attached.close()
+
 
 class TestDoiNormalize(unittest.TestCase):
     def test_plain(self):
@@ -126,7 +135,7 @@ class TestCrossrefPopulateVanilla(TestCrossrefPopulate):
     def setUpClass(cls):
         ensure_unlinked(DATABASE_PATH)
         FileCache.file_reads = 0
-        # debug.set_flags(["log-sql", "dump-matched"])
+        # debug.set_flags(["sql", "dump-matched"])
 
         cls.crossref = crossref.Crossref("tests/data/sample")
         cls.crossref.populate(DATABASE_PATH)
@@ -171,7 +180,7 @@ class TestCrossrefPopulateVanilla(TestCrossrefPopulate):
         )
         self.assertEqual(FileCache.file_reads, 8)
 
-    def test_work_countents(self):
+    def test_work_contents(self):
         self.assertEqual(
             self.cond_field(
                 "works", "publisher", "doi = '10.1016/j.bjps.2022.04.046'"
@@ -229,7 +238,7 @@ class TestCrossrefPopulateMasterCondition(TestCrossrefPopulate):
     def setUpClass(cls):
         ensure_unlinked(DATABASE_PATH)
         FileCache.file_reads = 0
-        # debug.set_flags(["log-sql", "dump-matched"])
+        # debug.set_flags(["sql", "dump-matched"])
 
         cls.crossref = crossref.Crossref("tests/data/sample")
         cls.crossref.populate(DATABASE_PATH, None, "issn_print = '16191366'")
@@ -253,7 +262,7 @@ class TestCrossrefPopulateDetailCondition(TestCrossrefPopulate):
     def setUpClass(cls):
         ensure_unlinked(DATABASE_PATH)
         FileCache.file_reads = 0
-        # debug.set_flags(["log-sql", "dump-matched"])
+        # debug.set_flags(["sql", "dump-matched"])
 
         cls.crossref = crossref.Crossref("tests/data/sample")
         cls.crossref.populate(
@@ -282,7 +291,7 @@ class TestCrossrefPopulateMasterColumnNoCondition(TestCrossrefPopulate):
         ensure_unlinked(DATABASE_PATH)
         FileCache.file_reads = 0
 
-        # debug.set_flags(["log-sql"])
+        # debug.set_flags(["sql"])
         cls.crossref = crossref.Crossref("tests/data/sample")
         cls.crossref.populate( DATABASE_PATH, ["works.doi"])
         cls.con = sqlite3.connect(DATABASE_PATH)
@@ -313,7 +322,7 @@ class TestCrossrefPopulateMasterColumnCondition(TestCrossrefPopulate):
         ensure_unlinked(DATABASE_PATH)
         FileCache.file_reads = 0
 
-        # debug.set_flags(["log-sql"])
+        # debug.set_flags(["sql"])
         cls.crossref = crossref.Crossref("tests/data/sample")
         cls.crossref.populate(
             DATABASE_PATH,
@@ -349,7 +358,7 @@ class TestCrossrefPopulateDetailConditionColumns(TestCrossrefPopulate):
         ensure_unlinked(DATABASE_PATH)
         FileCache.file_reads = 0
 
-        # debug.set_flags(["log-sql"])
+        # debug.set_flags(["sql"])
         cls.crossref = crossref.Crossref("tests/data/sample")
         cls.crossref.populate(
             DATABASE_PATH,
@@ -458,8 +467,13 @@ class TestCrossrefQuery(unittest.TestCase):
     """Verify non-works column specification and multiple conditions"""
 
     def setUp(self):
+        # debug.set_flags(["sql"])
         FileCache.file_reads = 0
-        self.crossref = crossref.Crossref("tests/data/sample")
+        populate_attached()
+        self.crossref = crossref.Crossref(
+            "tests/data/sample",
+            attach_databases=[f"attached:{ATTACHED_DATABASE_PATH}"]
+        )
 
     def test_works(self):
         for partition in True, False:
@@ -470,6 +484,19 @@ class TestCrossrefQuery(unittest.TestCase):
                 12,
             )
 
+    def test_works_attached(self):
+        for partition in True, False:
+            self.assertEqual(
+                record_count(
+                    self.crossref.query(
+            """SELECT * FROM works WHERE EXISTS (
+                SELECT 1 FROM attached.s_works WHERE works.doi = s_works.doi)
+            """, partition
+                    )
+                ),
+                1,
+            )
+
     def test_work_authors(self):
         for partition in True, False:
             self.assertEqual(
@@ -512,22 +539,17 @@ class TestCrossrefPopulateAttachedDatabaseCondition(TestCrossrefPopulate):
     def setUpClass(cls):
         ensure_unlinked(DATABASE_PATH)
         FileCache.file_reads = 0
+        populate_attached()
 
-        # Create and populate attached database
-        ensure_unlinked(ATTACHED_DATABASE_PATH)
-        attached = sqlite3.connect(ATTACHED_DATABASE_PATH)
-        attached.execute("CREATE TABLE s_works(doi)")
-        attached.execute("INSERT INTO s_works VALUES('10.1016/j.bjps.2022.04.046')")
-        attached.commit()
-        attached.close()
-
-        # debug.set_flags(["log-sql"])
-        cls.crossref = crossref.Crossref("tests/data/sample")
+        # debug.set_flags(["sql"])
+        cls.crossref = crossref.Crossref(
+            "tests/data/sample",
+            attach_databases=[f"attached:{ATTACHED_DATABASE_PATH}"]
+        )
         cls.crossref.populate(
             DATABASE_PATH,
             ["works.doi"],
             "EXISTS (SELECT 1 FROM attached.s_works WHERE works.doi = s_works.doi)",
-            [f"attached:{ATTACHED_DATABASE_PATH}"]
         )
         cls.con = sqlite3.connect(DATABASE_PATH)
         cls.cursor = cls.con.cursor()
